## cdist-type__rbenv(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__rbenv - Manage rbenv installation

## 2. DESCRIPTION

This cdist type allows you to manage rbenv installations. It also installs ruby-build.

## 3. OPTIONAL PARAMETERS

state
  Either "present" or "absent", defaults to "present"
owner
  Which user should own the rbenv installation, defaults to root

## 4. EXAMPLES

    # Install rbenv including ruby-build for nico
    __rbenv /home/nico

    # Install rbenv including ruby-build for nico
    __rbenv /home/nico --owner nico

    # Bastian does not need rbenv anymore, he began to code C99
    __rbenv /home/bastian --state absent

## 5. SEE ALSO

- cdist-type(7)

## 6. COPYING

Copyright (C) 2012-2014 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).